@@ -4,6 +4,7 @@
 # LICENSE file in the root directory of this source tree.
 
 import torch
+from torch.amp import autocast
 
 from xformers.components.attention import Attention, AttentionConfig, register_attention
 
@@ -19,10 +20,15 @@ class FourierMix(Attention):
         """
         super().__init__()
         self.attn_drop = torch.nn.Dropout(dropout, inplace=False)
+
+        # Properties specific to this attention mechanism
+        self.supports_attention_mask = False
         self.requires_input_projection = False
 
     def forward(self, q: torch.Tensor, *_, **__):
-        att = torch.fft.fft2(q).real
+        # Guard against autocast / fp16, not supported by torch.fft.fft2
+        with autocast("cuda", enabled=False):
+            att = torch.fft.fft2(q).real
 
         att = self.attn_drop(att)
 
